@@ -6,8 +6,11 @@ namespace DI\Test\UnitTest\Proxy\Fixtures;
 
 class ClassToProxy
 {
+    protected bool $initialized = false;
+
     public function foo()
     {
+        $this->initialized = true;
     }
 
     public function getInstance()
